@@ -47,6 +47,7 @@
 #include "config.h"
 #include "platform.h"
 #include "script.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -83,13 +84,12 @@ bool U61_Config::read()
   bool ok=false;
   char *filename;
 
-  //cout<<"read config\n";
+  U61_LOG_DEBUG("read config");
   filename=U61_Platform::get_config_file();
-  //cout<<"Loading config from \""<<filename<<"\".\n";
+  U61_LOG_MESSAGE("Loading config from \""<<filename<<"\".");
 
   U61_Script::do_file(filename);
 
-  //cout<<"coucou conf\n";
   if (read_int(ID_DUMMY,0)==DUMMY_VALUE)
     {
       ok=true;
@@ -134,7 +134,7 @@ void U61_Config::reset()
 
   max_fps=read_int(ID_MAX_FPS,18);
 
-  network_prevision=read_int(ID_NETWORK_PREVISION,false);
+  network_anticipation=read_int(ID_NETWORK_ANTICIPATION,false);
 
   for (pl=0;pl<NB_PLAYERS;++pl)
     {
@@ -150,8 +150,8 @@ void U61_Config::reset()
 	read_player_int(pl,ID_FIRST_REPEAT_OTHER,40);
       player[pl].standard_repeat_other=
 	read_player_int(pl,ID_STANDARD_REPEAT_OTHER,20);
-      player[pl].prevision=
-	read_player_int(pl,ID_PREVISION,false);
+      player[pl].anticipation=
+	read_player_int(pl,ID_ANTICIPATION,false);
     }
 
   player[0].activable=read_player_int(0,ID_ACTIVABLE,true);
@@ -165,7 +165,7 @@ void U61_Config::reset()
   player[0].key_drop=read_player_int(0,ID_KEY_DROP, CL_KEY_SPACE);
   player[0].key_next_victim=read_player_int(0,ID_KEY_NEXT_VICTIM, CL_KEY_W);
   player[0].key_prev_victim=read_player_int(0,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[0].key_use_antedote=read_player_int(0, ID_KEY_USE_ANTEDOTE, CL_KEY_R);
+  player[0].key_use_antidote=read_player_int(0, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
 
   player[1].activable=read_player_int(1,ID_ACTIVABLE,true);
   read_player_str(player[1].name,1,ID_NAME,"etoile");
@@ -178,7 +178,7 @@ void U61_Config::reset()
   player[1].key_drop=read_player_int(1,ID_KEY_DROP, CL_KEY_SPACE);
   player[1].key_next_victim=read_player_int(1,ID_KEY_NEXT_VICTIM, CL_KEY_W);
   player[1].key_prev_victim=read_player_int(1,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[1].key_use_antedote=read_player_int(1, ID_KEY_USE_ANTEDOTE, CL_KEY_R);
+  player[1].key_use_antidote=read_player_int(1, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
 
   player[2].activable=read_player_int(2,ID_ACTIVABLE,true);
   read_player_str(player[2].name,2,ID_NAME,"toto");
@@ -191,7 +191,7 @@ void U61_Config::reset()
   player[2].key_drop=read_player_int(2,ID_KEY_DROP, CL_KEY_SPACE);
   player[2].key_next_victim=read_player_int(2,ID_KEY_NEXT_VICTIM, CL_KEY_W);
   player[2].key_prev_victim=read_player_int(2,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[2].key_use_antedote=read_player_int(2, ID_KEY_USE_ANTEDOTE, CL_KEY_R);
+  player[2].key_use_antidote=read_player_int(2, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
 
   player[3].activable=read_player_int(3,ID_ACTIVABLE,true);
   read_player_str(player[3].name,3,ID_NAME,"zorro");
@@ -204,7 +204,7 @@ void U61_Config::reset()
   player[3].key_drop=read_player_int(3,ID_KEY_DROP, CL_KEY_SPACE);
   player[3].key_next_victim=read_player_int(3,ID_KEY_NEXT_VICTIM, CL_KEY_W);
   player[3].key_prev_victim=read_player_int(3,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[3].key_use_antedote=read_player_int(3, ID_KEY_USE_ANTEDOTE, CL_KEY_R);
+  player[3].key_use_antidote=read_player_int(3, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -218,11 +218,11 @@ bool U61_Config::write()
   FILE *file;
   int pl;
 
-  //cout<<"write config\n";
+  U61_LOG_DEBUG("write config");
   if (U61_Platform::create_user_dir())
     {
       filename=U61_Platform::get_config_file();
-      //cout<<"Writing config to \""<<filename<<"\".\n";
+      U61_LOG_MESSAGE("Writing config to \""<<filename<<"\".");
       file=fopen(filename,"w");
 
       if (file!=NULL)
@@ -250,7 +250,7 @@ bool U61_Config::write()
 
 	  ok=ok && write_int(file,ID_MAX_FPS, max_fps);
 
-	  ok=ok && write_int(file,ID_NETWORK_PREVISION, network_prevision);
+	  ok=ok && write_int(file,ID_NETWORK_ANTICIPATION, network_anticipation);
 
 	  for (pl=0;pl<NB_PLAYERS;++pl)
 	    {
@@ -267,8 +267,8 @@ bool U61_Config::write()
 	      ok=ok && write_player_int(pl,file,ID_STANDARD_REPEAT_OTHER,
 					player[pl].standard_repeat_other);
  
-	      ok=ok && write_player_int(pl,file,ID_PREVISION,
-					player[pl].prevision);
+	      ok=ok && write_player_int(pl,file,ID_ANTICIPATION,
+					player[pl].anticipation);
 
 	      ok=ok && write_player_int(pl,file,ID_ACTIVABLE,
 					player[pl].activable);
@@ -293,8 +293,8 @@ bool U61_Config::write()
 					player[pl].key_next_victim);
 	      ok=ok && write_player_int(pl,file,ID_KEY_PREV_VICTIM,
 					player[pl].key_prev_victim);
-	      ok=ok && write_player_int(pl,file,ID_KEY_USE_ANTEDOTE,
-					player[pl].key_use_antedote);
+	      ok=ok && write_player_int(pl,file,ID_KEY_USE_ANTIDOTE,
+					player[pl].key_use_antidote);
 	    } 
 
 	  fclose(file);
@@ -311,8 +311,6 @@ bool U61_Config::load_script()
 {
   bool ok=false;
 
-  //cout<<"Loading scripts from \""<<script_file<<"\".\n";
-
   ok=U61_Script::do_file(script_file);
     
   return ok;
