@@ -61,7 +61,7 @@
  */
 U61_Data::U61_Data()
 {
-
+  manager=NULL;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -81,13 +81,17 @@ void U61_Data::unload()
   /*
    * now we unload everything the manager loaded
    */
-  //cout<<"unload\n";
-  manager->unload_all_resources();
+  U61_LOG_DEBUG("unload");
+  if (manager!=NULL)
+    {
+      manager->unload_all_resources();
+
+      /*
+       * now the manager is freed
+       */
+      delete manager;
+    }
 
-  /*
-     * now the manager is freed
-     */
-  delete manager;
   manager=NULL;
 }
 
@@ -101,25 +105,55 @@ void U61_Data::unload()
 bool U61_Data::load1(char *name)
 {
   bool success=true;
-    
+
   /*
    * creation of the resource manager, which will be
    * used to load all the sections
    */
-  //cout<<"Loading data from \""<<name<<"\".\n";
-  manager=CL_ResourceManager::create(name,true);
-
-  if (manager!=NULL)
+  U61_LOG_MESSAGE("Loading data from \""<<name<<"\".");
+  /*
+   * We use a global try to catch errors from ClanLib's
+   * datafile reader. This try should only catch global
+   * errors such as being unable to find the datafile
+   */
+  try
     {
-      if (success)
-        {
-	  //cout<<"Loading properties\n";
-	  success=success && load_properties();
-        }
+      manager=CL_ResourceManager::create(name,true);
+
+      if (manager!=NULL)
+	{
+	  /*
+	   * We use a another try to catch errors from ClanLib's
+	   * datafile reader.
+	   */
+	  try
+	    {
+	      if (success)
+		{
+		  U61_LOG_DEBUG("Loading properties");
+		  success=success && load_properties();
+		}
+	      if (!success)
+		{
+		  U61_LOG_ERROR("Unknown error reading datafile, step 1");
+		}
+	    }
+	  catch(CL_Error e)
+	    {
+	      success=false;
+	      U61_LOG_ERROR("Error reading datafile, step 1: "<<e.message);
+	    }
+	}
+      else
+	{
+	  U61_LOG_ERROR("Unknown error creating resource manager, step 1"); 
+	  success=false;
+	}
     }
-  else
+  catch(CL_Error e)
     {
       success=false;
+      U61_LOG_ERROR("Error creating resource manager, step 1: "<<e.message);
     }
 
   return success;
@@ -133,57 +167,74 @@ bool U61_Data::load1(char *name)
 bool U61_Data::load2()
 {
   bool success=true;
-
+    
   if (manager!=NULL)
     {
       /*
-       * the following code loads all the different sections
-       * if one section fails, the load process is aborted
+       * We use a global try to catch errors from ClanLib's
+       * datafile reader.
        */
-      if (success)
-        {
-	  //cout<<"Loading fonts\n";
-	  success=success && load_fonts();
-        }
+      try
+	{
+	  /*
+	   * the following code loads all the different sections
+	   * if one section fails, the load process is aborted
+	   */
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading fonts");
+	      success=success && load_fonts();
+	    }
         
-      if (success)
-        {
-	  //cout<<"Loading sounds\n";
-	  success=success && load_sounds();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading sounds");
+	      success=success && load_sounds();
+	    }
         
-      if (success)
-        {
-	  //cout<<"Loading musics\n";
-	  success=success && load_musics();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading musics");
+	      success=success && load_musics();
+	    }
 
-      if (success)
-        {
-	  //cout<<"Loading squares\n";
-	  success=success && load_squares();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading square graphics");
+	      success=success && load_squares();
+	    }
 
-      if (success)
-        {
-	  //cout<<"Loading maps\n";
-	  success=success && load_maps();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading map graphics");
+	      success=success && load_maps();
+	    }
 
-      if (success)
-        {
-	  //cout<<"Loading background\n";
-	  success=success && load_back();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading background graphics");
+	      success=success && load_back();
+	    }
 
-      if (success)
-        {
-	  //cout<<"Loading info\n";
-	  success=success && load_info();
-        }
+	  if (success)
+	    {
+	      U61_LOG_DEBUG("Loading info graphics");
+	      success=success && load_info();
+	    }
+	  if (!success)
+	    {
+	      U61_LOG_ERROR("Unknown error reading datafile, step 2");
+	    }
+	}
+      catch(CL_Error e)
+	{
+	  success=false;
+	  U61_LOG_ERROR("Error reading datafile, step 2: "<<e.message);
+	}
     }
   else
     {
+      U61_LOG_ERROR("Unable to create resource manager, step 2"); 
       success=false;
     }
 
@@ -225,10 +276,10 @@ bool U61_Data::load_properties()
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_CURSES_X_BIG,manager);
   offset_curses_y[SIZE_BIG]=
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_CURSES_Y_BIG,manager);
-  offset_antedotes_x[SIZE_BIG]=
-    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTEDOTES_X_BIG,manager);
-  offset_antedotes_y[SIZE_BIG]=
-    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTEDOTES_Y_BIG,manager);
+  offset_antidotes_x[SIZE_BIG]=
+    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTIDOTES_X_BIG,manager);
+  offset_antidotes_y[SIZE_BIG]=
+    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTIDOTES_Y_BIG,manager);
   offset_next_curse_x[SIZE_BIG]=
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_NEXT_CURSE_X_BIG,manager);
   offset_next_curse_y[SIZE_BIG]=
@@ -258,10 +309,10 @@ bool U61_Data::load_properties()
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_CURSES_X_SMALL,manager);
   offset_curses_y[SIZE_SMALL]=
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_CURSES_Y_SMALL,manager);
-  offset_antedotes_x[SIZE_SMALL]=
-    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTEDOTES_X_SMALL,manager);
-  offset_antedotes_y[SIZE_SMALL]=
-    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTEDOTES_Y_SMALL,manager);
+  offset_antidotes_x[SIZE_SMALL]=
+    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTIDOTES_X_SMALL,manager);
+  offset_antidotes_y[SIZE_SMALL]=
+    CL_Res_Integer::load(ID_PROPERTY_OFFSET_ANTIDOTES_Y_SMALL,manager);
   offset_next_curse_x[SIZE_SMALL]=
     CL_Res_Integer::load(ID_PROPERTY_OFFSET_NEXT_CURSE_X_SMALL,manager);
   offset_next_curse_y[SIZE_SMALL]=
@@ -281,42 +332,17 @@ bool U61_Data::load_fonts()
   font_menu=CL_Font::load(ID_FONT_MENU,manager);
   success=success && (font_menu!=NULL);
    
-  if (!success)
-    {
-      cout<<"Font loading failed\n";
-    }
-
   font_info[SIZE_BIG]=CL_Font::load(ID_FONT_INFO_BIG,manager);
   success=success && (font_info[SIZE_BIG]!=NULL);
    
-  if (!success)
-    {
-      cout<<"Font loading failed\n";
-    }
-
   font_info[SIZE_SMALL]=CL_Font::load(ID_FONT_INFO_SMALL,manager);
   success=success && (font_info[SIZE_SMALL]!=NULL);
    
-  if (!success)
-    {
-      cout<<"Font loading failed\n";
-    }
-
   font_symbol[SIZE_BIG]=CL_Font::load(ID_FONT_SYMBOL_BIG,manager);
   success=success && (font_symbol[SIZE_BIG]!=NULL);
    
-  if (!success)
-    {
-      cout<<"Font loading failed\n";
-    }
-
   font_symbol[SIZE_SMALL]=CL_Font::load(ID_FONT_SYMBOL_SMALL,manager);
   success=success && (font_symbol[SIZE_SMALL]!=NULL);
-   
-  if (!success)
-    {
-      cout<<"Font loading failed\n";
-    }
 
   return success;
 }
@@ -350,11 +376,6 @@ bool U61_Data::load_sounds()
   sound_curse_receive=CL_SoundBuffer::load(ID_SOUND_CURSE_RECEIVE,manager);
   success=success && (sound_curse_receive!=NULL);
 
-  if (!success)
-    {
-      cout<<"Sound loading failed\n";
-    }
-
   return success;
 }
 
@@ -369,11 +390,6 @@ bool U61_Data::load_musics()
   //    mikmod_test=CL_Streamed_MikModSample::create("data/music/country.mod",NULL,true);
   //    success=success && (mikmod_test!=NULL);
    
-  if (!success)
-    {
-      cout<<"Music loading failed\n";
-    }
-
   return success;
 }
 
@@ -415,15 +431,15 @@ bool U61_Data::load_squares()
 
   strcpy(id,ID_SQUARE_SMALL);
   id[strlen(id)-1]=0;
-  strcat(id,ID_SQUARE_PREVISION);
-  prevision[SIZE_SMALL]=CL_Surface::load(id,manager);
-  success=success && (prevision[SIZE_SMALL]!=NULL);
+  strcat(id,ID_SQUARE_ANTICIPATION);
+  anticipation[SIZE_SMALL]=CL_Surface::load(id,manager);
+  success=success && (anticipation[SIZE_SMALL]!=NULL);
 
   strcpy(id,ID_SQUARE_BIG);
   id[strlen(id)-1]=0;
-  strcat(id,ID_SQUARE_PREVISION);
-  prevision[SIZE_BIG]=CL_Surface::load(id,manager);
-  success=success && (prevision[SIZE_BIG]!=NULL);
+  strcat(id,ID_SQUARE_ANTICIPATION);
+  anticipation[SIZE_BIG]=CL_Surface::load(id,manager);
+  success=success && (anticipation[SIZE_BIG]!=NULL);
 
   strcpy(id,ID_SQUARE_SMALL);
   id[strlen(id)-1]=0;
@@ -437,11 +453,7 @@ bool U61_Data::load_squares()
   explosion[SIZE_BIG]=CL_Surface::load(id,manager);
   success=success && (explosion[SIZE_BIG]!=NULL);
 
-  if (!success)
-    {
-      cout<<"Square loading failed\n";
-    }
-  else
+  if (success)
     {
       square_w[SIZE_SMALL]=square[0][SIZE_SMALL]->get_width();
       square_h[SIZE_SMALL]=square[0][SIZE_SMALL]->get_height();
@@ -476,11 +488,7 @@ bool U61_Data::load_maps()
     }
 
 
-  if (!success)
-    {
-      cout<<"Map loading failed\n";
-    }
-  else
+  if (success)
     {
       map_w[SIZE_SMALL]=map[0][SIZE_SMALL]->get_width();
       map_h[SIZE_SMALL]=map[0][SIZE_SMALL]->get_height();
@@ -505,11 +513,6 @@ bool U61_Data::load_back()
   shade=CL_Surface::load(ID_SHADE,manager);
   success=success && (shade!=NULL);
 
-  if (!success)
-    {
-      cout<<"Back loading failed\n";
-    }
-
   return success;
 }
 
@@ -526,11 +529,7 @@ bool U61_Data::load_info()
   info[SIZE_SMALL]=CL_Surface::load(ID_INFO_SMALL,manager);
   success=success && (info[SIZE_SMALL]!=NULL);
 
-  if (!success)
-    {
-      cout<<"Info loading failed\n";
-    }
-  else
+  if (success)
     {
       info_w[SIZE_SMALL]=info[SIZE_SMALL]->get_width();
       info_h[SIZE_SMALL]=info[SIZE_SMALL]->get_height();
