@@ -87,8 +87,8 @@ public:
     int offset_preview_y[NB_SIZE];
     int offset_curses_x[NB_SIZE];
     int offset_curses_y[NB_SIZE];
-    int offset_antedotes_x[NB_SIZE];
-    int offset_antedotes_y[NB_SIZE];
+    int offset_antidotes_x[NB_SIZE];
+    int offset_antidotes_y[NB_SIZE];
     int offset_next_curse_x[NB_SIZE];
     int offset_next_curse_y[NB_SIZE];
    
@@ -110,7 +110,7 @@ public:
  
     CL_Surface *square[NB_SQUARE_TYPE][NB_SIZE];
     CL_Surface *curse[NB_SIZE];
-    CL_Surface *prevision[NB_SIZE];
+    CL_Surface *anticipation[NB_SIZE];
     CL_Surface *explosion[NB_SIZE];
 
     CL_Surface *map[NB_MAP_MAX][NB_SIZE];
@@ -121,7 +121,7 @@ public:
     CL_Surface *info[NB_SIZE];
 
     static char *const SYMBOL_CURSE="-";
-    static char *const SYMBOL_ANTEDOTE="+";
+    static char *const SYMBOL_ANTIDOTE="+";
 
 protected:
     CL_ResourceManager *manager;
@@ -153,10 +153,10 @@ protected:
                          "property/offset_curses_x_big";
     static char *const ID_PROPERTY_OFFSET_CURSES_Y_BIG=
                          "property/offset_curses_y_big";
-    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_X_BIG=
-                         "property/offset_antedotes_x_big";
-    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_Y_BIG=
-                         "property/offset_antedotes_y_big";
+    static char *const ID_PROPERTY_OFFSET_ANTIDOTES_X_BIG=
+                         "property/offset_antidotes_x_big";
+    static char *const ID_PROPERTY_OFFSET_ANTIDOTES_Y_BIG=
+                         "property/offset_antidotes_y_big";
     static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_X_BIG=
                          "property/offset_next_curse_x_big";
     static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_Y_BIG=
@@ -186,10 +186,10 @@ protected:
                          "property/offset_curses_x_small";
     static char *const ID_PROPERTY_OFFSET_CURSES_Y_SMALL=
                          "property/offset_curses_y_small";
-    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_X_SMALL=
-                         "property/offset_antedotes_x_small";
-    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_Y_SMALL=
-                         "property/offset_antedotes_y_small";
+    static char *const ID_PROPERTY_OFFSET_ANTIDOTES_X_SMALL=
+                         "property/offset_antidotes_x_small";
+    static char *const ID_PROPERTY_OFFSET_ANTIDOTES_Y_SMALL=
+                         "property/offset_antidotes_y_small";
     static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_X_SMALL=
                          "property/offset_next_curse_x_small";
     static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_Y_SMALL=
@@ -212,7 +212,7 @@ protected:
     static char *const ID_SQUARE_BIG="square/big_n";
     static char *const ID_SQUARE_SMALL="square/small_n";
     static char *const ID_SQUARE_CURSE="curse";
-    static char *const ID_SQUARE_PREVISION="prevision";
+    static char *const ID_SQUARE_ANTICIPATION="anticipation";
     static char *const ID_SQUARE_EXPLOSION="explosion";
 
     static char *const ID_MAP_BIG="map/big_";
