@@ -44,6 +44,7 @@
 #include "edit.h"
 #include "const.h"
 #include "menuinput.h"
+#include "global.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -100,50 +101,51 @@ bool U61_Edit::action(int key)
   bool changed=false;
   int len;
   int i;
+  int ascii;
 
   len=strlen(value); 
 
-  if (isalnum(key) || key==' ')
+  switch (key)
     {
-      for (i=len;i>=pos;--i)
-	{
-	  value[i+1]=value[i];
-	}
-      value[pos]=key;
-      value[MAX_SIZE]=0;
+    case CL_KEY_RIGHT:
       pos++;
-      changed=true;
-    }
-  else
-    {
-      switch (key)
-        {
-        case U61_MenuInput::KEY_RIGHT:
-	  pos++;
-	  break;
-        case U61_MenuInput::KEY_LEFT:
+      break;
+    case CL_KEY_LEFT:
+      pos--;
+      break;
+    case CL_KEY_DELETE:
+      if (pos>=len && pos>0)
+	{
 	  pos--;
-	  break;
-        case U61_MenuInput::KEY_DELETE:
-	  if (pos>=len && pos>0)
-            {
-	      pos--;
-            }
-	  if (len>0)
-            {
-	      suppress();
-	      changed=true;
-            }
-	  break;
-        case U61_MenuInput::KEY_BACKSPACE:
-	  if (pos>0)
-            {
-	      pos--;
-	      suppress();
-	      changed=true;
-            }
-	  break;
-        }
+	}
+      if (len>0)
+	{
+	  suppress();
+	  changed=true;
+	}
+      break;
+    case CL_KEY_BACKSPACE:
+      if (pos>0)
+	{
+	  pos--;
+	  suppress();
+	  changed=true;
+	}
+      break;
+    default:
+      ascii=U61_Global::game.scan_code_to_ascii(key);
+      if (isalnum(ascii) || ascii==' ')
+	{
+	  for (i=len;i>=pos;--i)
+	    {
+	      value[i+1]=value[i];
+	    }
+	  value[pos]=ascii;
+	  value[MAX_SIZE]=0;
+	  pos++;
+	  changed=true;
+	}
+      break;
     }
   check_pos();
 
