@@ -60,6 +60,8 @@
 #include "serverdispatcher.h"
 #include "localdispatcher.h"
 #include "utils.h"
+#include "game.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -76,7 +78,7 @@
  */ 
 U61_Game::U61_Game()
 {
-  //    cout<< "U61 game object created\n";
+
 }
 
 /*--------------------------------------------------------------------------*/
@@ -85,7 +87,12 @@ U61_Game::U61_Game()
  */ 
 U61_Game::~U61_Game()
 {
-  //    cout << "Display : " <<  calls_to_display << " Logic : " << calls_to_logic << " Menu : " << calls_to_menu << " Poll : " << calls_to_poll << " Poll CL : " << calls_to_poll_clanlib << " Poll U61 : " << calls_to_poll_u61 << "\n";
+  U61_LOG_DEBUG("Display : "<<calls_to_display);
+  U61_LOG_DEBUG(" Logic : "<<calls_to_logic);
+  U61_LOG_DEBUG("Menu : "<<calls_to_menu); 
+  U61_LOG_DEBUG("Poll : "<<calls_to_poll);
+  U61_LOG_DEBUG("Poll CL : "<<calls_to_poll_clanlib); 
+  U61_LOG_DEBUG("Poll U61 : "<<calls_to_poll_u61);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -135,9 +142,6 @@ bool U61_Game::init(char *filename)
       success=success && U61_Global::data.load2();
     }  
 
-  //cout<<"Setting video mode\n";
-  //CL_Display::set_videomode(640,480,16,false);
-
   return success;
 }
 
@@ -303,6 +307,7 @@ void U61_Game::poll()
 	  last_menu_time_polled=clanlib_time;   
 
 	  menu_input.poll(u61_time);
+          menu_input.poll_mouse();
 
 	  calls_to_poll_menu++;     
         }
@@ -318,7 +323,6 @@ void U61_Game::poll()
             {
 	      player_input[i].poll(u61_time);
             }
-	  //cout<<"polled "<<ticks_now<<"\n";
 
 	  calls_to_poll_u61++;     
         }
@@ -381,6 +385,7 @@ void U61_Game::menu()
 {
   U61_Menu *next_menu;
   U61_Event key;
+  int mouse_y;
 
   next_menu=current_menu;
 
@@ -390,6 +395,13 @@ void U61_Game::menu()
       next_menu=current_menu->action(key.code);
     }
 
+  mouse_y=menu_input.get_mouse_y();
+  if (mouse_y>=0)
+    {
+      U61_LOG_DEBUG("mouse_y="<<mouse_y);
+      next_menu=current_menu->mouse_action(mouse_y);
+    }
+
   if (next_menu==NULL)
     {
       quit();
@@ -416,7 +428,6 @@ void U61_Game::network()
   int i;
   int slot;
 
-  //cout<<"Network polled\n"; 
   if (protocol!=NULL)
     {
       if (protocol->send_all()==U61_Protocol::FAILED 
@@ -433,7 +444,7 @@ void U61_Game::network()
 	{
           if (dispatcher->is_player_busy(i) && !exists_player_id(i))
 	    {
-              //cout<<"Should create player "<<i<<"\n";
+              U61_LOG_DEBUG("Should create player "<<i);
               slot=find_free_network_slot();
               if (slot>=0)
 		{
@@ -444,6 +455,29 @@ void U61_Game::network()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the current menu. Usefull when one wants to call pop_menu,
+ * since a menu must always be created with a parent
+ */
+U61_Menu *U61_Game::get_current_menu()
+{
+  return current_menu;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Forces the current menu to be replaced by the given menu.
+ * This is usefull when on wants to prompt the user with a 
+ * question. A good example (the only one?) is the 
+ * menu which asks the player if he wants to save the script
+ * or not, when he's connecting to a server.
+ */
+void U61_Game::force_menu(U61_Menu *m)
+{
+  current_menu=m;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * retrieves parameters from the config , which can not change during
@@ -475,7 +509,7 @@ void U61_Game::configure_hot()
  */
 void U61_Game::start_quick()
 {
-  //cout<<"quick start\n";
+  U61_LOG_DEBUG("quick start");
   start_local_alone();
 }
 
@@ -487,14 +521,14 @@ void U61_Game::start_local_alone()
 {
   int num;
 
-  //cout<<"local alone game started\n";
+  U61_LOG_DEBUG("local alone game started");
   if (standard_init())
     {
       dispatcher=new U61_LocalDispatcher();
 
       num=get_local_player(0);
-      //cout<<"num="<<num<<"\n";
-      //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
+      U61_LOG_DEBUG("num="<<num);
+      U61_LOG_DEBUG("name="<<U61_Global::config.player[num].name);
       player[0].init_local(&(player_input[num]),dispatcher,
 			   0,0,
 			   &(U61_Global::config.player[num]));
@@ -509,7 +543,7 @@ void U61_Game::start_local_alone()
 void U61_Game::start_local_multiplayer()
 {
   int num0,num1,num2,num3;
-  //cout<<"local multiplayer game started\n";
+  U61_LOG_DEBUG("local multiplayer game started");
   if (standard_init())
     {
       dispatcher=new U61_LocalDispatcher();
@@ -574,7 +608,7 @@ void U61_Game::start_network_new()
   int num0,num1;
   U61_ServerDispatcher *d;
 
-  //cout<<"new network game started\n";
+  U61_LOG_DEBUG("new network game started");
   if (standard_init())
     {
       d=new U61_ServerDispatcher();
@@ -619,7 +653,7 @@ void U61_Game::start_network_join()
 {
   U61_ClientDispatcher *d;
 
-  //cout<<"joining network game\n";
+  U61_LOG_DEBUG("joining network game");
   
   if (standard_init())
     {
@@ -705,7 +739,7 @@ void U61_Game::stop()
   reset_players();
   U61_Global::layout.reset();
   stop_network();
-  //cout<<"game stopped\n";
+  U61_LOG_DEBUG("game stopped");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -945,3 +979,15 @@ U61_Player *U61_Game::find_player_by_id(int id)
 
   return result;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Translates a scan code, used internally to recognize keys, into
+ * an ascii code usable in strings. This function is an ugly hack
+ * I created because menu_input wasn't accessible from U61_Global...
+ */
+int U61_Game::scan_code_to_ascii(int scan_code)
+{
+  return menu_input.get_ascii(scan_code);
+}
+
