@@ -103,6 +103,11 @@ class U61_Game
   int acceleration;
   int curse_delay;
 
+  U61_Menu *get_current_menu();
+  void force_menu(U61_Menu *m);
+
+  int scan_code_to_ascii(int scan_code);
+
  protected:
   char exe_name[U61_STRING_SIZE];
   U61_MenuInput menu_input;
