@@ -73,6 +73,16 @@ U61_Game U61_Global::game;
  */
 U61_Layout U61_Global::layout;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * The buffers of the RemoteScript class are declared global
+ * because it was quite tricky to handle them as arguments
+ * since the script has to be saved at the end of the game,
+ * when the ClientProtocol class (which reads the remote
+ * script) has been deleted.
+ */
+U61_RemoteScript U61_Global::remote_script;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
