@@ -50,6 +50,7 @@
 #include "data.h"
 #include "game.h"
 #include "layout.h"
+#include "remotescript.h"
 
 /*---------------------------------------------------------------------------
  classes
@@ -62,6 +63,7 @@ public:
     static U61_Data data;
     static U61_Game game;
     static U61_Layout layout;
+    static U61_RemoteScript remote_script;
 protected:
 };
 
