@@ -41,6 +41,7 @@
  ---------------------------------------------------------------------------*/
 
 #include "key.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -103,7 +104,7 @@ void U61_Key::fire(int time)
     queue.push_back(event);
 
     last_fired=time;
-    //cout<<"fire code="<<time<<"\n";
+    U61_LOG_DEBUG("fire "<<event<<" at time "<<time);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -116,9 +117,6 @@ void U61_Key::poll(int time)
 
     pressed=CL_Keyboard::get_keycode(code_in);    
 
-    //cout<<"key poll "<<time<<"\n";
-
-    //cout<<"p";
     if (pressed)
     {
         switch (state)
@@ -126,21 +124,18 @@ void U61_Key::poll(int time)
         case RELEASED:
             state=PRESSED;
             fire(time);
-     //       cout<<"pressed when RELEASED\n";
             break;
         case PRESSED:
             if (time-last_fired>first_delay)
 	    {
                 state=REPEATING;
                 fire(last_fired+first_delay);
-       //         cout<<"pressed when PRESSED\n";
 	    }
             break;
         case REPEATING:
             while (time-last_fired>standard_delay)
 	    {
                 fire(last_fired+standard_delay);
-         //       cout<<"pressed when REPEATING\n";
 	    }
             break;
 	}  
@@ -160,7 +155,6 @@ void U61_Key::reset()
 {
     last_fired=0;
     state=RELEASED;
-    //cout<<"key reseted\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -185,7 +179,6 @@ U61_Event U61_Key::get()
     event=queue.front();
     queue.pop_front();
 
-    //cout<<"key "<<event<<"\n";
     return event;
 }
 
