@@ -50,6 +50,7 @@
 #include "time.h"
 #include "sound.h"
 #include "utils.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -114,7 +115,8 @@ void U61_Map::clear()
 	  squares[i][j].set_color((i+j)%8);
         }
     }
-  curse_state=false;
+  curse_chosen=false;
+  curse_asked=false;
   curse_x=0;
   curse_y=0;
 }
@@ -144,11 +146,14 @@ void U61_Map::begin()
   speed=base_speed;
   accel=base_accel; 
   background=0;
-  prevision_state=true;
+  anticipation_state=true;
   preview_state=true;
   match_count=0;
-  curse_counter=curse_delay;
-  nb_antedote=0;
+  curse_counter=0;
+  curse_chosen=false;
+  curse_asked=false;
+  curse_state=false;
+  nb_antidote=0;
   if (score>best_score)
     {
       best_score=score;
@@ -238,7 +243,7 @@ void U61_Map::set_inactive()
  */
 void U61_Map::change_background()
 {
-  //cout<<"Number of backgrounds"<<U61_Global::data.nb_map<<"\n";
+  U61_LOG_DEBUG("Number of backgrounds"<<U61_Global::data.nb_map);
   background=U61_Utils::random(U61_Global::data.nb_map);
 }
 
@@ -303,7 +308,14 @@ void U61_Map::set_score(int s)
 {
   if (s>=0)
     {
-      score=s;
+      if (s<MAX_SCORE)
+	{
+          score=s;
+	}
+      else
+        {
+	  score=MAX_SCORE-1;
+	}
     }
   else
     {
@@ -420,7 +432,6 @@ int U61_Map::get_curse_age(int i)
 	}
     }
 
-  //cout<<"Age="<<age<<"\n";
   return age;
 }
 
@@ -443,8 +454,7 @@ void U61_Map::register_curse(int i, int length)
 	}
       curse_begin[i]=map_time;
       curse_end[i]=map_time+length*U61_Time::ONE_SECOND;
-      //cout<<"Registering "<<i<<" begin="<<curse_begin[i]
-      //  <<" end="<<curse_end[i]<<"\n";
+      U61_LOG_DEBUG("Registering "<<i<<" begin="<<curse_begin[i]<<" end="<<curse_end[i]);
     }
 }
 
@@ -508,31 +518,31 @@ int U61_Map::get_nb_curse()
 
 /*--------------------------------------------------------------------------*/
 /*
- * Returns the number of antedotes
+ * Returns the number of antidotes
  */
-int U61_Map::get_nb_antedote()
+int U61_Map::get_nb_antidote()
 {
-  return nb_antedote;
+  return nb_antidote;
 }
 
 /*--------------------------------------------------------------------------*/
 /*
- * Adds an antedote
+ * Adds an antidote
  */
-void U61_Map::add_antedote()
+void U61_Map::add_antidote()
 {
-  nb_antedote++;
+  nb_antidote++;
 }
 
 /*--------------------------------------------------------------------------*/
 /*
- * Deletes an antedote
+ * Deletes an antidote
  */
-void U61_Map::delete_antedote()
+void U61_Map::delete_antidote()
 {
-  if (nb_antedote>0)
+  if (nb_antidote>0)
     {
-      nb_antedote--;
+      nb_antidote--;
     }
 }
 
@@ -566,7 +576,15 @@ void U61_Map::set_curse_y(int y)
  */
 void U61_Map::set_curse_state(bool state)
 {
-  curse_state=(state!=false);
+  if (state)
+    {
+      curse_state=true;
+    }
+  else
+    {
+      curse_counter=0;
+      curse_state=false;
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -575,7 +593,14 @@ void U61_Map::set_curse_state(bool state)
  */
 int U61_Map::get_curse_x()
 {
-  return curse_x;
+  int x=-1;
+
+  if (curse_state && curse_chosen)
+    {
+      x=curse_x;
+    }
+
+  return x;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -584,7 +609,14 @@ int U61_Map::get_curse_x()
  */
 int U61_Map::get_curse_y()
 {
-  return curse_y;
+  int y=-1;
+
+  if (curse_state && curse_chosen)
+    {
+      y=curse_y;
+    }
+
+  return y;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -606,7 +638,7 @@ bool U61_Map::is_curse_available()
   bool result=false;
 
   if (curse_x>=0 && curse_y>=0 && curse_x<WIDTH && curse_y<HEIGHT
-      && curse_state
+      && curse_state && curse_chosen
       && squares[curse_x][curse_y].is_enabled())
     {
       result=true;
@@ -627,7 +659,7 @@ void U61_Map::send_curse(int curse_id)
 
   if (player_id!=target_id && curse_id>=0 && curse_id<MAX_CURSE_ID)
     {
-      //cout<<"Sending curse "<<curse_id<<"\n";
+      U61_LOG_DEBUG("Sending curse "<<curse_id);
 
       evt.code=U61_Event::REQUEST_CURSE;
       evt.par=curse_id;
@@ -665,7 +697,6 @@ char *U61_Map::get_curse_name()
  */
 void U61_Map::compute_next()
 {
-  //cout<<"Compute next\n";
   map_time++;
   curse_counter++;
   update_explosions();
@@ -677,6 +708,10 @@ void U61_Map::compute_next()
     {
       check_target();
     }
+  if (!(map_time%CHECK_CURSE_DELAY))
+    {
+      check_curse();
+    }
   if (!exists_explosion())
     {
       match_pattern();
@@ -705,7 +740,7 @@ void U61_Map::update_speed()
     {
       accel_counter-=ACCEL_SCALE;
       speed++;
-      //cout<<"Next speed ("<<speed<<")\n";
+      U61_LOG_DEBUG("Next speed ("<<speed);
     }    
 
   check_speed();
@@ -737,9 +772,7 @@ void U61_Map::handle_event(U61_Event *event)
     {
       if (int(event->time)<map_time)
         {
-	  cout<<"Inconsitency in event dates detected event="
-	      <<*event<<" map_time="
-	      <<map_time<<"\n";
+	  U61_LOG_DEBUG("Inconsitency in event dates detected with event "<<*event<<" and map_time="<<map_time);
         }  
       else
         {
@@ -791,14 +824,14 @@ void U61_Map::handle_event(U61_Event *event)
             case U61_Event::DO_CURSE:
               do_curse(*event);
 	      break;
-            case U61_Event::USE_ANTEDOTE:
-              use_antedote();
+            case U61_Event::USE_ANTIDOTE:
+              use_antidote();
               break;
             }
         }
     }
 
-  //cout<<"Event low level computed="<<event<<"\n";
+  U61_LOG_DEBUG("Event computed "<<*event);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -849,16 +882,19 @@ void U61_Map::poll_auto_events()
 	  event.code=U61_Event::NEW_BLOCK;
 	  event.par=U61_Script::new_shape(this,&block);
 	  put_auto_event(event);
-	  //cout<<"new block event sent\n";
+	  U61_LOG_DEBUG("new block event sent");
         }
-      if (curse_counter>curse_delay 
+      if (curse_state
+          && (((!curse_asked) && (!curse_chosen)) 
+	      || curse_counter>curse_delay)
 	  && (!exists_explosion()))
 	{
+	  curse_asked=true;
 	  curse_counter=0;
           event.code=U61_Event::NEW_CURSE;
           event.par=U61_Script::new_curse(this,&block);
           put_auto_event(event);
-          //cout<<"Auto curse event "<<event.par<<"\n";
+          U61_LOG_DEBUG("Auto curse event "<<event.par);
 	}
     }
 }
@@ -944,7 +980,7 @@ char *U61_Map::get_name()
 /*
  * draws the map onto the screen
  */
-void U61_Map::draw(int x,int y, int size, bool prev)
+void U61_Map::draw(int x,int y, int size, bool anti)
 {
   int i,j;
   int x_square_offset;
@@ -976,7 +1012,8 @@ void U61_Map::draw(int x,int y, int size, bool prev)
 		+j*U61_Global::data.square_h[size];
 
               if (j==curse_y && i==curse_x && 
-		  curse_state && squares[i][j].is_enabled())
+		  curse_state && curse_chosen &&
+                  squares[i][j].is_enabled())
 		{
                   if (U61_Square::should_blink())
 		    {
@@ -993,13 +1030,12 @@ void U61_Map::draw(int x,int y, int size, bool prev)
 		}
             }
         }
-      if (prevision_state && prev)
+      if (anticipation_state && anti)
         {
-	  draw_prevision(x_square_offset,y_square_offset,size);
+	  draw_anticipation(x_square_offset,y_square_offset,size);
         }
       block.draw(x_square_offset,y_square_offset,size);
     }
-  //    cout<<"draw square\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1013,20 +1049,20 @@ void U61_Map::mute()
 
 /*--------------------------------------------------------------------------*/
 /*
- * sets the prevision state
+ * sets the anticipation state
  */
-void U61_Map::set_prevision_state(bool state)
+void U61_Map::set_anticipation_state(bool state)
 {
-  prevision_state=state; 
+  anticipation_state=state; 
 }
 
 /*--------------------------------------------------------------------------*/
 /*
- * gets the prevision state
+ * gets the anticipation state
  */
-bool U61_Map::get_prevision_state()
+bool U61_Map::get_anticipation_state()
 {
-  return prevision_state; 
+  return anticipation_state; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1177,10 +1213,10 @@ bool U61_Map::exists_explosion()
 
 /*--------------------------------------------------------------------------*/
 /*
- * display the prevision, the prevision is "where the block will land if
+ * display the anticipation, the anticipation is "where the block will land if
  * nothing happens" ie where it will land if I press drop  
  */
-void U61_Map::draw_prevision(int x,int y,int size)
+void U61_Map::draw_anticipation(int x,int y,int size)
 {
   U61_Block test;
   U61_Block prev;
@@ -1197,7 +1233,7 @@ void U61_Map::draw_prevision(int x,int y,int size)
         }
 
       U61_Script::land(this,&prev);
-      prev.draw_prevision(x,y,size); 
+      prev.draw_anticipation(x,y,size); 
     }
 }
 
@@ -1208,9 +1244,10 @@ void U61_Map::draw_prevision(int x,int y,int size)
  */
 void U61_Map::block_rotate_left()
 {
-  //cout<<"rotate left\n";
   U61_Block test;
 
+  U61_LOG_DEBUG("rotate left");
+
   test=block;
   U61_Script::rotate_left(this,&test);
   test.center();
@@ -1251,9 +1288,10 @@ void U61_Map::block_rotate_left()
  */
 void U61_Map::block_rotate_right()
 {
-  //cout<<"rotate right\n";
   U61_Block test;
 
+  U61_LOG_DEBUG("rotate right");
+
   test=block;
   U61_Script::rotate_right(this,&test);
   test.center();
@@ -1294,9 +1332,10 @@ void U61_Map::block_rotate_right()
  */
 void U61_Map::block_move_left()
 {
-  //cout<<"move left\n";
   U61_Block test;
 
+  U61_LOG_DEBUG("move left");
+
   test=block;
   U61_Script::move_left(this,&test);
   test.center();
@@ -1313,9 +1352,10 @@ void U61_Map::block_move_left()
  */
 void U61_Map::block_move_right()
 {
-  //cout<<"move right\n";
   U61_Block test;
 
+  U61_LOG_DEBUG("move right");
+
   test=block;
   U61_Script::move_right(this,&test);
   test.center();
@@ -1332,7 +1372,6 @@ void U61_Map::block_move_right()
  */
 void U61_Map::block_move_down()
 {
-  //cout<<"move down\n";
   U61_Block test;
 
   test=block;
@@ -1354,9 +1393,10 @@ void U61_Map::block_move_down()
  */
 void U61_Map::block_drop()
 {
-  //cout<<"drop\n";
   U61_Block test;
 
+  U61_LOG_DEBUG("drop");
+
   test=block;
   if (block.get_nb_items()>0)
     {
@@ -1389,15 +1429,21 @@ void U61_Map::name_add_letter(char c)
 
 /*--------------------------------------------------------------------------*/
 /*
- * Uses an antedote
+ * Uses an antidote
  */
-void U61_Map::use_antedote()
+void U61_Map::use_antidote()
 {
-  //cout<<"Using antedote\n";
-  if (nb_antedote>0)
+  U61_LOG_DEBUG("Using antidote");
+
+  if (nb_antidote>0)
     {
-      nb_antedote--;
-      U61_Script::use_antedote(this);
+      nb_antidote--;
+      U61_Script::use_antidote(this,&block);
+      /*
+       * The call to check_block is very important since use_antidote
+       * has full rights on the map and block.
+       */
+      check_block();
     }
 }
 
@@ -1472,7 +1518,7 @@ void U61_Map::new_block(int shape)
   next_block.corner();
   block.center();
 
-  //cout<<"new block given\n";
+  U61_LOG_DEBUG("new block given");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1486,6 +1532,18 @@ void U61_Map::stabilize_block()
   int x,y,i,n;
   bool outside=false;
 
+  /*
+   * Before we merge the block with the map, we move the block up
+   * until there's no conflict with the map. At first sight, it seems
+   * useless since usually stabilize comes after a move_down, but it's
+   * just safest to do this check, since many things can happen in
+   * a curse for instance.
+   */
+  while (!is_block_ok(&block))
+    {
+      block.set_y(block.get_y()-1);
+    }
+
   U61_Script::land(this,&block);
   n=block.get_nb_items();
   for (i=0;i<n;++i)
@@ -1521,7 +1579,8 @@ void U61_Map::stabilize_block()
  */
 void U61_Map::loose()
 {
-  //cout<<"The game is lost\n";
+  U61_LOG_DEBUG("The game is lost");
+
   begin();
 }
 
@@ -1566,6 +1625,11 @@ void U61_Map::match_pattern()
 void U61_Map::time_callback()
 {
   U61_Script::time_callback(this,&block);
+  /*
+   * The call to check_block is very important since time_callback
+   * has full rights on the map and block.
+   */
+  check_block();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1594,7 +1658,7 @@ void U61_Map::update_explosions()
              * is the special curse square, then we need to launch the
              * script associated to this curse
              */
-            if (curse_state && curse_x==x && curse_y==y)
+            if (curse_state && curse_chosen && curse_x==x && curse_y==y)
 	      {
                 curse_exploded=true;
 	      }
@@ -1620,7 +1684,8 @@ void U61_Map::update_explosions()
        * The curse has been used so we disable it and ask for another one
        * by forcing curse_counter to curse_delay
        */
-      curse_state=false;
+      curse_chosen=false;
+      curse_asked=false;
       curse_counter=curse_delay;
     }
 }
@@ -1638,7 +1703,7 @@ void U61_Map::new_curse(int id)
   int x,y;
   int pos,chosen_pos;
  
-  //cout<<"New curse\n";
+  U61_LOG_DEBUG("New curse");
 
   nb_squares=0;
   for (y=0;y<HEIGHT;++y)
@@ -1650,7 +1715,7 @@ void U61_Map::new_curse(int id)
 	    nb_squares++;
 	  }
       }
-  //cout<<"nb_squares="<<nb_squares<<"\n";
+  U61_LOG_DEBUG("nb_squares="<<nb_squares);
   if (nb_squares>0)
     {
       /*
@@ -1673,14 +1738,15 @@ void U61_Map::new_curse(int id)
 		  {
 		    curse_x=x;
 		    curse_y=y;
-		    //cout<<"Curse chosen x="<<x<<" y="<<y<<"\n";
+		    U61_LOG_DEBUG("Curse chosen x="<<x<<" y="<<y);
 		  }
 		pos++;
 	      }	
 	  }
       
       curse_id=id;
-      curse_state=true;
+      curse_chosen=true;
+      curse_asked=false;
     }
 }
 
@@ -1709,14 +1775,39 @@ void U61_Map::do_curse(U61_Event evt)
 {
   if (evt.par<(unsigned int) MAX_CURSE_ID)
     {
-      //cout<<"Do own curse "<<evt<<"\n";
-      U61_Script::do_curse(this,evt.par,false);
+      U61_LOG_DEBUG("Do own curse "<<evt);
+      U61_Script::do_curse(this,&block,evt.par,false);
     }
   else
     {
       evt.par-=MAX_CURSE_ID;
-      //cout<<"Do remote curse "<<evt<<"\n";
-      U61_Script::do_curse(this,evt.par,true);
+      U61_LOG_DEBUG("Do remote curse "<<evt);
+      U61_Script::do_curse(this,&block,evt.par,true);
+    }
+  /*
+   * The call to check_block is very important since do_curse
+   * has full rights on the map and block.
+   */
+  check_block();
+}
+
+/*-------------------------------------------------------------------------*/
+/*
+ * Re-enables the curse_state if it has been inactive for too long
+ * It also asks sets the curse_chosen parameter to false if there's no
+ * curse available (this will cause a new curse to be chosen).
+ * We use this mecanism to avoid calling is_curse_available all the time.
+ */
+void U61_Map::check_curse()
+{
+  if (curse_counter>=curse_delay)
+    {
+      curse_state=true;
+    }
+  if (curse_state==true && !is_curse_available())
+    {
+      curse_chosen=false;
+      curse_asked=false;
     }
 }
 
@@ -1729,7 +1820,7 @@ void U61_Map::next_victim(U61_Event *event)
   target_id=U61_Global::layout.get_next_player_id(target_id,player_id);
   event->code=U61_Event::SET_VICTIM;
   event->par=target_id;
-  //cout<<"Next victim "<<target_id<<"\n";
+  U61_LOG_DEBUG("Next victim "<<target_id);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -1741,7 +1832,7 @@ void U61_Map::prev_victim(U61_Event *event)
   target_id=U61_Global::layout.get_prev_player_id(target_id,player_id);
   event->code=U61_Event::SET_VICTIM;
   event->par=target_id;
-  //cout<<"Prev victim "<<target_id<<"\n";
+  U61_LOG_DEBUG("Prev victim "<<target_id);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -1751,7 +1842,7 @@ void U61_Map::prev_victim(U61_Event *event)
 void U61_Map::set_victim(int id)
 {
   target_id=id;
-  //cout<<"Set victim "<<target_id<<"\n";
+  U61_LOG_DEBUG("Set victim "<<target_id);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -1779,7 +1870,121 @@ void U61_Map::check_target()
       event.code=U61_Event::SET_VICTIM;
       event.par=test_id;
       put_auto_event(event);
-      //      cout<<"Correcting victim "<<test_id<<"\n";
+      U61_LOG_DEBUG("Correcting victim "<<test_id);
     }  
 }
 
+/*-------------------------------------------------------------------------*/
+/*
+ * This function is very important. It checks that the block has a correct
+ * position. It is called after most of the Lua scripts which can
+ * modify the block and/or the map. Indeed, it is important not to leave
+ * the map in an incoherent position.
+ * So this function moves the block sideways if it's too much on the left
+ * or too much on the right, and then it moves it up until there's no
+ * inconsistency.
+ */
+void U61_Map::check_block()
+{
+  int i,n,x;
+  int min_x,max_x;
+  U61_Block test;
+  bool ok;
+
+  n=block.get_nb_items();
+
+  /*
+   * First step, we check that the block is not on the right or on
+   * the left. Basically we want to put it "back in the middle"
+   */
+  min_x=WIDTH-1;
+  max_x=0;
+  for (i=0;i<n;++i)
+    {
+      x=block.get_x()+block.get_item_x(i);
+      if (x<min_x)
+	{
+	  min_x=x;
+	}
+      if (x>max_x)
+	{
+	  max_x=x;
+	}
+    }
+  /*
+   * we move the block to the right if needed
+   */
+  if (min_x<0)
+    {
+      block.set_x(block.get_x()-min_x);
+    }
+  /*
+   * we move the block to the left if needed
+   */
+  if (max_x>WIDTH-1)
+    {
+      block.set_x(block.get_x()-max_x+WIDTH-1);
+    }
+
+  /*
+   * Now we are going to move the block up until it fits correctly.
+   * This should solve a very common problem, which is that when
+   * you fill the map with garbage, the block may be stuck in the
+   * new added blocks. Therefore we move the block up. Note that in
+   * this case the user is very likely to be in trouble to place the
+   * block correctly, but there's no way to solve this except make
+   * the block disappear, which is not a very good solution.
+   */
+  ok=is_block_ok(&block);
+  while (!ok)
+    {
+      test=block;
+      /*
+       * we move the block up of 1 square
+       */
+      block.set_y(test.get_y()-1);
+      if (!is_block_ok(&block))
+	{
+          /*
+           * Ok, now if we get here it means one step up is not enough.
+           * So what we'll do is try to move the block sideways a little
+           * bit. This avoid the ridiculous situation where a block "climbs"
+           * a very high wall to get stuck on it while there's plenty of
+           * room elsewhere in the map.
+           */
+	  test.set_x(test.get_x()-1);
+          if (is_block_ok(&test))
+	    {
+	      /*
+	       * The block is OK after it has been moved on the left
+	       */
+	      block=test;
+	      ok=true;
+	    }
+          else
+	    {
+	      test.set_x(test.get_x()+2);
+	      if (is_block_ok(&test))
+		{
+		  /*
+		   * The block is OK after it has been moved on the right
+		   */
+		  block=test;
+		  ok=true;
+		}
+	    }
+	}
+      else
+	{
+	  /*
+	   * The block is OK after it has been moved up.
+	   * We move it up of one more square to give the player a chance to place
+	   * it, otherwise it would be really unfair. However, it's still hard
+	   * to place it correctly, but it's the game...
+	   */
+	  block.set_y(block.get_y()-1);
+	  ok=true;
+	}
+    }
+}
+
