@@ -56,6 +56,7 @@ class U61_Menu
   virtual ~U61_Menu();
     
   U61_Menu *action(int key);
+  U61_Menu *mouse_action(int mouse_y);
   virtual U61_Menu *validate();
   virtual U61_Menu *back();
   void draw();
@@ -77,6 +78,7 @@ class U61_Menu
   char *top_message;
 
   static bool shaded;
+  static bool force_update;
   bool message_active;
 
   void draw_top_message();
