@@ -38,25 +38,26 @@ public:
     ~U61_MenuInput();
  
     void init();
-    int reverse_scan_code(int ascii);
+    char get_ascii(int code);
     char *get_label(int code);
 
-    const static int KEY_LEFT=8;
-    const static int KEY_RIGHT=9;
-    const static int KEY_UP=11;
-    const static int KEY_DOWN=10;
-    const static int KEY_ENTER=13;
-    const static int KEY_ESCAPE=0;
-    const static int KEY_DELETE=20;
-    const static int KEY_BACKSPACE=21;
+    void poll_mouse();
+    int get_mouse_y();
+
 protected:
     void set_menu_key(int i,int cl_code,int ascii,char *label);
 
-    const static int NB_KEYS=80;
+    const static int MOUSE_DELAY=50;
+    const static int NB_KEYS=100;
     const static int REPEAT_FIRST=50;
     const static int REPEAT_STANDARD=15;
 
     char *keys_label[NB_KEYS];
+    char keys_ascii[NB_KEYS];
+
+    int mouse_last_fired;
+    int mouse_y;
 };
 
 #endif
+
