@@ -48,6 +48,7 @@
 #include "menuitem.h"
 #include "global.h"
 #include "letter.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -64,7 +65,7 @@
  */ 
 U61_MenuItem::U61_MenuItem()
 {
-    U61_MenuItem("Default menu item");
+  U61_MenuItem("Default menu item");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -73,8 +74,10 @@ U61_MenuItem::U61_MenuItem()
  */ 
 U61_MenuItem::U61_MenuItem(char *str)
 {
-    set_text(str);
-    unselect();
+  mouse_up_limit=0;
+  mouse_down_limit=0;
+  set_text(str);
+  unselect();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -92,7 +95,7 @@ U61_MenuItem::~U61_MenuItem()
  */
 bool U61_MenuItem::action(int key)
 {
-    //cout<<"menu item action"<<key<<"\n"; 
+  U61_LOG_DEBUG("menu item action, key="<<key) 
     return false;
 }
 
@@ -111,25 +114,28 @@ void U61_MenuItem::update()
  */
 void U61_MenuItem::draw(int y)
 {
-    int x;
-    int i;
-    int nb_letter;
-    int last_letter_width2;
-    int letter_width;
+  int x;
+  int i;
+  int nb_letter;
+  int last_letter_width2;
+  int letter_width;
 
-    x=U61_Global::data.screen_w/2;
+  x=U61_Global::data.screen_w/2;
+  x-=get_width()/2;
 
-    x-=get_width()/2;
-    last_letter_width2=0;
+  mouse_up_limit=y;
+  mouse_down_limit=y+get_height();  
 
-    nb_letter=text.size();    
-    for (i=0;i<nb_letter;++i)
+  last_letter_width2=0;
+
+  nb_letter=text.size();    
+  for (i=0;i<nb_letter;++i)
     {
-        letter_width=text[i].get_width();
+      letter_width=text[i].get_width();
         
-        x+=last_letter_width2+letter_width/2;
-        text[i].draw(x,y);
-        last_letter_width2=letter_width-letter_width/2;
+      x+=last_letter_width2+letter_width/2;
+      text[i].draw(x,y);
+      last_letter_width2=letter_width-letter_width/2;
     }
 }
 
@@ -139,17 +145,17 @@ void U61_MenuItem::draw(int y)
  */
 int U61_MenuItem::get_height()
 {
-    int i;
-    int nb_letter;
-    int height=0;
+  int i;
+  int nb_letter;
+  int height=0;
 
-    nb_letter=text.size();
-    for (i=0;i<nb_letter;++i)
+  nb_letter=text.size();
+  for (i=0;i<nb_letter;++i)
     {
-        height=max(text[i].get_height(),height);
+      height=max(text[i].get_height(),height);
     }
 
-    return height;
+  return height;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -158,17 +164,17 @@ int U61_MenuItem::get_height()
  */
 int U61_MenuItem::get_width()
 {
-    int i;
-    int nb_letter;
-    int width=0;
+  int i;
+  int nb_letter;
+  int width=0;
 
-    nb_letter=text.size();
-    for (i=0;i<nb_letter;++i)
+  nb_letter=text.size();
+  for (i=0;i<nb_letter;++i)
     {
-        width+=text[i].get_width();
+      width+=text[i].get_width();
     }
 
-    return width;
+  return width;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -177,7 +183,7 @@ int U61_MenuItem::get_width()
  */
 void U61_MenuItem::select_char(int i)
 {
-    text[i].enable_dance();
+  text[i].enable_dance();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -186,13 +192,13 @@ void U61_MenuItem::select_char(int i)
  */
 void U61_MenuItem::select_right(int start)
 {
-    int i;
-    int nb_letter;
+  int i;
+  int nb_letter;
     
-    nb_letter=text.size();
-    for (i=start;i<nb_letter;++i)
+  nb_letter=text.size();
+  for (i=start;i<nb_letter;++i)
     {
-        select_char(i);
+      select_char(i);
     }
 }
 
@@ -202,7 +208,7 @@ void U61_MenuItem::select_right(int start)
  */
 void U61_MenuItem::select()
 {
-    select_right(0);
+  select_right(0);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -211,13 +217,13 @@ void U61_MenuItem::select()
  */
 void U61_MenuItem::unselect()
 {
-    int i;
-    int nb_letter;
+  int i;
+  int nb_letter;
     
-    nb_letter=text.size();
-    for (i=0;i<nb_letter;++i)
+  nb_letter=text.size();
+  for (i=0;i<nb_letter;++i)
     {
-        text[i].disable_dance();
+      text[i].disable_dance();
     }
 }
 
@@ -227,16 +233,16 @@ void U61_MenuItem::unselect()
  */
 void U61_MenuItem::set_text(char *str)
 {
-    text.clear();
-    /*
-     * we fill the vector of letters with the chars of the string
-     * passed in arg, this will simply create a menu item that
-     * display the string
-     */
-    while(*str)
+  text.clear();
+  /*
+   * we fill the vector of letters with the chars of the string
+   * passed in arg, this will simply create a menu item that
+   * display the string
+   */
+  while(*str)
     {
-        text.push_back(U61_Letter(U61_Global::data.font_menu,*str));
-        str++;
+      text.push_back(U61_Letter(U61_Global::data.font_menu,*str));
+      str++;
     } 
 }
 
@@ -246,17 +252,17 @@ void U61_MenuItem::set_text(char *str)
  */
 void U61_MenuItem::put_text(char *buf)
 {
-    int i;
-    int nb_letter;
-    char c;
+  int i;
+  int nb_letter;
+  char c;
     
-    nb_letter=text.size();
-    for (i=0;i<nb_letter;++i)
+  nb_letter=text.size();
+  for (i=0;i<nb_letter;++i)
     {
-        c=text[i].get_ascii();
-        buf[i]=c;
+      c=text[i].get_ascii();
+      buf[i]=c;
     }
-    buf[i]=0;
+  buf[i]=0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -265,5 +271,21 @@ void U61_MenuItem::put_text(char *buf)
  */
 bool U61_MenuItem::is_modal()
 { 
-    return false;
+  return false;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if a mouse click at this height should infuence the item
+ */
+bool U61_MenuItem::is_mouse_in(int y)
+{
+  bool ok=false;
+
+  if (y>=mouse_up_limit && y<mouse_down_limit)
+    {
+      ok=true;
+    }
+
+  return ok;
 }
