@@ -58,28 +58,32 @@
 
 class U61_MenuItem
 {
-public:
-    U61_MenuItem();
-    U61_MenuItem(char *str);
-    virtual ~U61_MenuItem();
+ public:
+  U61_MenuItem();
+  U61_MenuItem(char *str);
+  virtual ~U61_MenuItem();
 
-    virtual bool action(int key);
-    virtual void update();
-    void draw(int y);
-    int get_width();
-    int get_height();
-    void set_text(char *str);
-    void put_text(char *buf);
+  virtual bool action(int key);
+  virtual void update();
+  void draw(int y);
+  int get_width();
+  int get_height();
+  void set_text(char *str);
+  void put_text(char *buf);
 
-    void select_char(int i);
-    void select_right(int start);
-    virtual void select();
-    virtual void unselect();
-    virtual bool is_modal();
-protected:
-    vector<U61_Letter> text;    
-    bool selected;
-    static char *const SEPARATOR=" : ";
+  void select_char(int i);
+  void select_right(int start);
+  virtual void select();
+  virtual void unselect();
+  virtual bool is_modal();
+
+  bool is_mouse_in(int y);
+ protected:
+  vector<U61_Letter> text;    
+  bool selected;
+  static char *const SEPARATOR=" : ";
+  int mouse_up_limit;
+  int mouse_down_limit;
 };
 
 #endif
