@@ -64,7 +64,7 @@ U61_NetworkOptionMenu::U61_NetworkOptionMenu(U61_Menu *parent,
 {
   config=conf;
   add_item(new U61_Edit("Server",conf->server_id));
-  add_item(new U61_Toggle("Prevision mode is",&(conf->network_prevision),
+  add_item(new U61_Toggle("Anticipation mode is",&(conf->network_anticipation),
                             "on","off"));
   add_item(new U61_EditNumber("TCP/IP port",
 			      &(conf->network_port),1000,10000));
