@@ -142,12 +142,12 @@ bool U61_Number::action(int key)
 
     switch (key)
     {
-    case U61_MenuInput::KEY_ENTER:
-    case U61_MenuInput::KEY_RIGHT:
+    case CL_KEY_ENTER:
+    case CL_KEY_RIGHT:
         changed=true;
         inc();
         break;
-    case U61_MenuInput::KEY_LEFT:
+    case CL_KEY_LEFT:
         changed=true;
         dec();
         break;
