@@ -44,14 +44,26 @@
 #include <dirent.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <syslog.h>
 
 #include "platform.h"
 #include "const.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * The file is used to log the debug messages, it is stored in ~/.u61 and
+ * not in /var/log since it can get enormous and as it is used for
+ * debugging, it is to be used by a developper (me for instance) and
+ * I find it more convenient to have this file in my own directory tree
+ * with my permissions
+ */
+static FILE *debug_file=NULL;
+
 /*--------------------------------------------------------------------------*/
 /*
  * global variables for directory scan functions
@@ -196,6 +208,53 @@ char *U61_Platform::get_config_file()
   return buffer;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * transforms "/usr/local/share/u61/script/classic.lua" into "classic"
+ */
+void U61_Platform::strip_remote_script_path(char *path)
+{
+  char buffer[U61_STRING_SIZE];
+  char *pos;
+
+  /*
+   * We remove the path (directories part)
+   */
+  pos=strrchr(path,'/');
+  if (pos!=NULL)
+    {
+      strcpy(buffer,pos+1);
+      strcpy(path,buffer);
+    }
+
+  /*
+   * We remove the extension
+   */
+  pos=strrchr(path,'.');
+  if (pos!=NULL)
+    {
+      pos[0]=0;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * transforms "classic" into "/home/ufoot/.u61/script/classic.lua"
+ */
+void U61_Platform::unstrip_remote_script_path(char *path)
+{
+  char buffer[U61_STRING_SIZE];
+
+  // Gets the user script path "/home/ufoot/.u61/script/"
+  strncpy(buffer,get_user_script_path(),sizeof(buffer)-1);
+  // Add the filename "classic"
+  strcat(buffer,path);
+  // Add the extension ".lua"
+  strcat(buffer,".lua");
+
+  strncpy(path,buffer,sizeof(buffer)-1);
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * opens a directory for file scanning
@@ -304,16 +363,148 @@ bool U61_Platform::create_user_dir()
  */
 void U61_Platform::exec(char *file)
 {
-  //cout<<"executing \""<<file<<"\"\n";
+  char buffer[U61_STRING_SIZE];
+  int len;
+
+  U61_LOG_MESSAGE("Restarting...");
+  U61_Debug::deinit();
 
   CL_SetupCore::deinit_network();    
   CL_SetupCore::deinit_sound();
   CL_SetupCore::deinit_display();
   CL_SetupCore::deinit();
 
-  // This function should never return
+  /*
+   * First we try to launch the executable described
+   * by argv[0]. This succeeds in case the exe is ./u61
+   * or something with a full path. execl shouldn't
+   * returns if it succeeds
+   */
   execl(file,file,NULL);
+
+  /*
+   * now the first attempt has failed, we try again
+   * by appending INSTALL_BIN_PATH before argv[0].
+   * this should replace u61 by /usr/local/bin/u61
+   * for instance.
+   */
+  strcpy(buffer,INSTALL_BIN_PATH);
+  len=strlen(buffer);
+  if (len>0)
+    {
+      if (buffer[len-1]!='/')
+        {
+	  strcat(buffer,"/");
+        } 
+    }
+  strcat(buffer,file);
+  execl(buffer,buffer,NULL);
+
+  /*
+   * Now if we get there, it means there's an error.
+   * Since we have uninitialized ClanLib, we *must*
+   * quit, or there's a core dump arround the corner...
+   */
+  U61_Debug::init();
+  U61_LOG_ERROR("Unable to execute "<<file<<" or "<<buffer);
+  U61_Debug::deinit();
+
+  exit(1);
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Opens all the log files, on UNIX, this concerns only the debug log
+ * file, since the rest of the log is handled by syslog
+ */
+void U61_Platform::open_log_files()
+{
+  openlog("u61",LOG_PID,LOG_USER);
 
+#ifdef DEBUG
+  char buffer[U61_STRING_SIZE];
+
+  strcpy (buffer,get_user_path());
+  strcat(buffer,"debug.log");
+
+  debug_file=fopen(buffer,"w");
+#endif
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Closes all the log files, on UNIX, this concerns only the debug log
+ * file, since the rest of the log is handled by syslog
+ */
+void U61_Platform::close_log_files()
+{
+#ifdef DEBUG
+  if (debug_file!=NULL)
+    {
+      fclose(debug_file);
+    }
+#endif
+
+  debug_file=NULL;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Logs an error message with syslog and in the debug log if needed
+ */
+void U61_Platform::log_to_error_file(char *text)
+{
+  syslog(LOG_ERR,"error: %s",text);
+
+#ifdef DEBUG
+  if (debug_file!=NULL)
+    {
+      fprintf(debug_file,"*;error  ;%25s;%-5d;%s\n","unknown",0,text);
+    }
+#endif
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Logs a warning message with syslog and in the debug log if needed
+ */
+void U61_Platform::log_to_warning_file(char *text)
+{
+  syslog(LOG_WARNING,"warning: %s",text);
+
+#ifdef DEBUG
+  if (debug_file!=NULL)
+    {
+      fprintf(debug_file,"*;warning;%25s;%-5d;%s\n","unknown",0,text);
+    }
+#endif
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Logs a standard message with syslog and in the debug log if needed
+ */
+void U61_Platform::log_to_message_file(char *text)
+{
+#ifdef DEBUG
+  if (debug_file!=NULL)
+    {
+      fprintf(debug_file," ;message;%25s;%-5d;%s\n","unknown",0,text);
+    }
+#endif
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Logs a debug message with syslog and in the debug log if needed
+ */
+void U61_Platform::log_to_debug_file(char *text,char *file,int line)
+{
+#ifdef DEBUG
+  if (debug_file!=NULL)
+    {
+      fprintf(debug_file," ;debug  ;%25s;%-5d;%s\n",file,line,text);
+    }
+#endif
+}
 
