@@ -62,6 +62,7 @@
 #include "networksource.h"
 #include "networkcopy.h"
 #include "global.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -187,11 +188,11 @@ int U61_Player::get_nb_curse()
 
 /*--------------------------------------------------------------------------*/
 /*
- * returns the number of antedotes available
+ * returns the number of antidotes available
  */
-int U61_Player::get_nb_antedote()
+int U61_Player::get_nb_antidote()
 {
-  return last.get_nb_antedote();
+  return last.get_nb_antidote();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -225,12 +226,12 @@ void U61_Player::init_local(U61_Input *input,
 
   set_id(id);
   sure.init(id,
-	     U61_Global::game.initial_speed,
-	     U61_Global::game.acceleration,
-             U61_Global::game.curse_delay);
+	    U61_Global::game.initial_speed,
+	    U61_Global::game.acceleration,
+	    U61_Global::game.curse_delay);
   copy_sure_to_last();
 
-  prevision=&(conf->prevision);
+  anticipation=&(conf->anticipation);
 
   src=new U61_LocalSource(input,&sure,d,id,conf->name);
   if (start)
@@ -262,12 +263,12 @@ void U61_Player::init_network(U61_Dispatcher *d,
 
   set_id(id);
   sure.init(id,
-	     U61_Global::game.initial_speed,
-	     U61_Global::game.acceleration,
-             U61_Global::game.curse_delay);
+	    U61_Global::game.initial_speed,
+	    U61_Global::game.acceleration,
+	    U61_Global::game.curse_delay);
   copy_sure_to_last();
 
-  prevision=&(U61_Global::config.network_prevision);
+  anticipation=&(U61_Global::config.network_anticipation);
 
   src=new U61_NetworkSource(d,&sure,id);
   cpy=new U61_NetworkCopy(id,d);
@@ -275,7 +276,7 @@ void U61_Player::init_network(U61_Dispatcher *d,
   source=src;
   copy=cpy;
 
-  //cout<<"Starting network player "<<id<<"\n";
+  U61_LOG_DEBUG("Starting network player "<<id);
 
   available=true;
 }
@@ -360,23 +361,23 @@ void U61_Player::pump_events()
  */
 void U61_Player::handle_event(U61_Event *evt)
 {
-      if (sure.is_active())
+  if (sure.is_active())
+    {
+      if (evt->code==U61_Event::START_STOP)
 	{
-	  if (evt->code==U61_Event::START_STOP)
-	    {
-	      stop();
-	    }
-	  else
-	    {
-	      sure.handle_event(evt);
-	    }
+	  stop();
 	}
       else
 	{
-	  if (evt->code==U61_Event::START_STOP)
-	    {
-	      start(evt->time);
-	    } 
+	  sure.handle_event(evt);
+	}
+    }
+  else
+    {
+      if (evt->code==U61_Event::START_STOP)
+	{
+	  start(evt->time);
+	} 
     }
 }
 
@@ -388,7 +389,7 @@ void U61_Player::start(int time)
 {
   sure.set_active(time);
   copy_sure_to_last();
-  //cout<<"Player "<<id<<" started\n";
+  U61_LOG_DEBUG("Player "<<id<<" started");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -399,7 +400,7 @@ void U61_Player::stop()
 {
   sure.set_inactive();
   copy_sure_to_last();
-  //cout<<"Player "<<id<<" stopped\n";
+  U61_LOG_DEBUG("Player "<<id<<" stopped");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -412,7 +413,7 @@ void U61_Player::kill()
 {
   reset();
   //available=false;
-  //cout<<"Player "<<id<<" killed\n";
+  U61_LOG_DEBUG("Player "<<id<<" killed");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -423,7 +424,7 @@ void U61_Player::draw(int x,int y,int size)
 {
   last.anticipate(U61_Time::for_event());
   //last.draw(10,10);
-  last.draw(x,y,size,*prevision);
+  last.draw(x,y,size,*anticipation);
 }
 
 /*--------------------------------------------------------------------------*/
