@@ -48,6 +48,7 @@
 #include "packet.h"
 #include "version.h"
 #include "const.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -176,7 +177,7 @@ int U61_Protocol::send_id(U61_Connection *conn)
 {
   int result=LATER;
 
-  // cout<<"Sending ID\n";
+  U61_LOG_DEBUG("Sending ID");
 
   if (conn->send(GAME_ID,strlen(GAME_ID)))
     {
@@ -195,7 +196,7 @@ int U61_Protocol::recv_id(U61_Connection *conn)
   int result=LATER;
   char buffer[U61_STRING_SIZE];
 
-  // cout<<"Receiving ID\n";
+  U61_LOG_DEBUG("Receiving ID");
 
   if (conn->peek())
     {
@@ -204,7 +205,7 @@ int U61_Protocol::recv_id(U61_Connection *conn)
           if (strcmp(GAME_ID,buffer)==0)
 	    {
 	      result=DONE;
-	      //cout<<"Received ID "<<buffer<<"\n";
+	      U61_LOG_DEBUG("Received ID "<<buffer<<"");
 	    }
           else
 	    {
@@ -233,7 +234,7 @@ int U61_Protocol::send_version(U61_Connection *conn)
   int result=LATER;
   char version[U61_STRING_SIZE];
 
-  // cout<<"Sending version\n";
+  U61_LOG_DEBUG("Sending version");
 
   U61_Version::get_version_text(version);
 
@@ -255,7 +256,7 @@ int U61_Protocol::recv_version(U61_Connection *conn)
   char version[U61_STRING_SIZE];
   char buffer[U61_STRING_SIZE];
 
-  //  cout<<"Receiving version\n";
+  U61_LOG_DEBUG("Receiving version");
 
   U61_Version::get_version_text(version);
   if (conn->peek())
@@ -265,7 +266,7 @@ int U61_Protocol::recv_version(U61_Connection *conn)
           if (strcmp(version,buffer)==0)
 	    {
 	      result=DONE;
-	      //cout<<"Received version "<<buffer<<"\n";
+	      U61_LOG_DEBUG("Received version "<<buffer<<"");
 	    }
           else
 	    {
@@ -290,7 +291,7 @@ int U61_Protocol::send_ready(U61_Connection *conn)
 {
   int result=LATER;
 
-  // cout<<"Sending ready message\n";
+  U61_LOG_DEBUG("Sending ready message");
 
   if (conn->send(READY_MESSAGE,strlen(READY_MESSAGE)))
     {
@@ -309,7 +310,7 @@ int U61_Protocol::recv_ready(U61_Connection *conn)
   int result=LATER;
   char buffer[U61_STRING_SIZE];
 
-  // cout<<"Receiving ready message\n";
+  U61_LOG_DEBUG("Receiving ready message");
 
   if (conn->peek())
     {
@@ -318,7 +319,7 @@ int U61_Protocol::recv_ready(U61_Connection *conn)
           if (strcmp(READY_MESSAGE,buffer)==0)
 	    {
 	      result=DONE;
-	      //cout<<"Received ID "<<buffer<<"\n";
+	      U61_LOG_DEBUG("Received ID "<<buffer<<"");
 	    }
           else
 	    {
@@ -341,6 +342,6 @@ int U61_Protocol::recv_ready(U61_Connection *conn)
  */
 void U61_Protocol::print_diagnostic()
 {
-  cout<<"Network error : "<<diagnostic<<"\n";
+  U61_LOG_WARNING("Network error : "<<diagnostic);
 }
 
