@@ -40,6 +40,7 @@
  ---------------------------------------------------------------------------*/
 
 #include "serverdispatcher.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -84,7 +85,7 @@ bool U61_ServerDispatcher::open(U61_Connection *c)
   bool ok=true;
   U61_Event evt;
 
-  //cout<<"Opening connection\n";
+  U61_LOG_MESSAGE("Opening connection");
   connection.push_back(c);
 
   /*
@@ -96,7 +97,7 @@ bool U61_ServerDispatcher::open(U61_Connection *c)
     {
       if (history[i].playing())
 	{
-          //cout<<"Sending history for player "<<i<<"\n";
+          U61_LOG_DEBUG("Sending history for player "<<i<<"");
           for (j=0;j<(int) history[i].size();++j)
 	    {
               evt=history[i].get(j);
@@ -109,7 +110,7 @@ bool U61_ServerDispatcher::open(U61_Connection *c)
     }
   if (!ok)
     {
-      cout<<"Impossible to send complete history, too much data???\n";
+      U61_LOG_WARNING("Impossible to send complete history, too much data???");
     }
 
   return ok;
@@ -125,6 +126,8 @@ void U61_ServerDispatcher::close(U61_Connection *c)
   int size;
   vector<U61_Connection *> temp;
 
+  U61_LOG_MESSAGE("Closing connection");
+
   /*
    * I could not find out how to remove an item from a vector,
    * if you know just send me a mail! (ufoot@ufoot.org)
@@ -159,7 +162,7 @@ bool U61_ServerDispatcher::send(U61_Event evt)
   size=connection.size();
   for (i=0;i<size;++i)
     {
-      //cout<<"Sending event "<<evt<<" on connection "<<i<<"\n";
+      U61_LOG_DEBUG("Sending event "<<evt<<" on connection "<<i<<"");
       if (!connection[i]->send(evt))
 	{
 	  ok=false;
