@@ -67,8 +67,6 @@ U61_SpeedMenu::U61_SpeedMenu(U61_Menu *parent,
              &(conf->acceleration),0,U61_Map::MAX_USER_ACCEL));
     add_item(new U61_Number("Curse delay",
              &(conf->curse_delay),2,60));
-    add_item(new U61_Number("Max frames per sec",
-             &(conf->max_fps),5,50));
     select(0);
 }
 
