@@ -37,10 +37,11 @@
  includes
  ---------------------------------------------------------------------------*/
 
-#include "utils.h"
-
 #include <stdlib.h>
 
+#include "utils.h"
+#include "debug.h"
+
 /*---------------------------------------------------------------------------
  variants
  ---------------------------------------------------------------------------*/
@@ -117,9 +118,9 @@ bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 		    }
 		  catch (CL_Error e)
 		    {
-		      cout<<"Invalid video mode: w="<<w
-			  <<" h="<<h
-			  <<" fullscreen="<<fullscreen<<"\n";
+		      U61_LOG_WARNING("Invalid video mode: w="<<w
+				      <<" h="<<h
+				      <<" fullscreen="<<fullscreen);
 		    }
 		}
 	    }
